@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader::Authorities;
 # ABSTRACT: Chargeur de notices d'autorité
-$Koha::Contrib::Sudoc::Loader::Authorities::VERSION = '2.36';
+$Koha::Contrib::Sudoc::Loader::Authorities::VERSION = '2.37';
 use Moose;
 
 extends 'Koha::Contrib::Sudoc::Loader';
@@ -40,7 +40,7 @@ sub handle_record {
         }
     }
     unless ( $authtypecode ) {
-        $self->warning("  ERREUR : Autorité sans vedette\n");
+        $self->log->warning("  ERREUR : Autorité sans vedette\n");
         return;
     }
 
@@ -148,7 +148,7 @@ Koha::Contrib::Sudoc::Loader::Authorities - Chargeur de notices d'autorité
 
 =head1 VERSION
 
-version 2.36
+version 2.37
 
 =head1 AUTHOR
 
@@ -156,7 +156,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Fréderic Demians.
+This software is Copyright (c) 2022 by Fréderic Demians.
 
 This is free software, licensed under:
 
